@@ -28,33 +28,31 @@
 
 #include <cron.h>
 
-typedef	enum ecode {
+typedef enum ecode {
 	e_none, e_minute, e_hour, e_dom, e_month, e_dow,
 	e_cmd, e_timespec, e_username, e_option, e_memory
 } ecode_e;
 
-static const char *ecodes[] =
-	{
-		"no error",
-		"bad minute",
-		"bad hour",
-		"bad day-of-month",
-		"bad month",
-		"bad day-of-week",
-		"bad command",
-		"bad time specifier",
-		"bad username",
-		"bad option",
-		"out of memory"
-	};
+static const char *ecodes[] = {
+	"no error",
+	"bad minute",
+	"bad hour",
+	"bad day-of-month",
+	"bad month",
+	"bad day-of-week",
+	"bad command",
+	"bad time specifier",
+	"bad username",
+	"bad option",
+	"out of memory"
+};
 
-static int	get_list(bitstr_t *, int, int, const char *[], int, FILE *),
-		get_range(bitstr_t *, int, int, const char *[], int, FILE *),
-		get_number(int *, int, const char *[], int, FILE *, const char *),
-		set_element(bitstr_t *, int, int, int);
+static int get_list(bitstr_t *, int, int, const char *[], int, FILE *),
+get_range(bitstr_t *, int, int, const char *[], int, FILE *),
+get_number(int *, int, const char *[], int, FILE *, const char *),
+set_element(bitstr_t *, int, int, int);
 
-void
-free_entry(entry *e) {
+void free_entry(entry * e) {
 	free(e->cmd);
 	free(e->pwd);
 	env_free(e->envp);
@@ -64,8 +62,8 @@ free_entry(entry *e) {
 /* return NULL if eof or syntax error occurs;
  * otherwise return a pointer to a new entry.
  */
-entry *
-load_entry(FILE *file, void (*error_func)(), struct passwd *pw, char **envp) {
+entry *load_entry(FILE * file, void (*error_func) (), struct passwd *pw,
+	char **envp) {
 	/* this function reads one crontab entry -- the next -- from a file.
 	 * it skips any leading blank lines, ignores comments, and returns
 	 * NULL if for any reason the entry can't be read and parsed.
@@ -74,12 +72,12 @@ load_entry(FILE *file, void (*error_func)(), struct passwd *pw, char **envp) {
 	 *
 	 * syntax:
 	 *   user crontab:
-	 *	minutes hours doms months dows cmd\n
+	 *  minutes hours doms months dows cmd\n
 	 *   system crontab (/etc/crontab):
-	 *	minutes hours doms months dows USERNAME cmd\n
+	 *  minutes hours doms months dows USERNAME cmd\n
 	 */
 
-	ecode_e	ecode = e_none;
+	ecode_e ecode = e_none;
 	entry *e;
 	int ch;
 	char cmd[MAX_COMMAND];
@@ -88,7 +86,7 @@ load_entry(FILE *file, void (*error_func)(), struct passwd *pw, char **envp) {
 
 	Debug(DPARS, ("load_entry()...about to eat comments\n"))
 
-	skip_comments(file);
+		skip_comments(file);
 
 	ch = get_char(file);
 	if (ch == EOF)
@@ -99,7 +97,7 @@ load_entry(FILE *file, void (*error_func)(), struct passwd *pw, char **envp) {
 	 * of a list of minutes.
 	 */
 
-	e = (entry *) calloc(sizeof(entry), sizeof(char));
+	e = (entry *) calloc(sizeof (entry), sizeof (char));
 
 	if (ch == '@') {
 		/* all of these should be flagged and load-limited; i.e.,
@@ -117,41 +115,47 @@ load_entry(FILE *file, void (*error_func)(), struct passwd *pw, char **envp) {
 		ch = get_string(cmd, MAX_COMMAND, file, " \t\n");
 		if (!strcmp("reboot", cmd)) {
 			e->flags |= WHEN_REBOOT;
-		} else if (!strcmp("yearly", cmd) || !strcmp("annually", cmd)){
+		}
+		else if (!strcmp("yearly", cmd) || !strcmp("annually", cmd)) {
 			bit_set(e->minute, 0);
 			bit_set(e->hour, 0);
 			bit_set(e->dom, 0);
 			bit_set(e->month, 0);
-			bit_nset(e->dow, 0, (LAST_DOW-FIRST_DOW+1));
+			bit_nset(e->dow, 0, (LAST_DOW - FIRST_DOW + 1));
 			e->flags |= DOW_STAR;
-		} else if (!strcmp("monthly", cmd)) {
+		}
+		else if (!strcmp("monthly", cmd)) {
 			bit_set(e->minute, 0);
 			bit_set(e->hour, 0);
 			bit_set(e->dom, 0);
-			bit_nset(e->month, 0, (LAST_MONTH-FIRST_MONTH+1));
-			bit_nset(e->dow, 0, (LAST_DOW-FIRST_DOW+1));
+			bit_nset(e->month, 0, (LAST_MONTH - FIRST_MONTH + 1));
+			bit_nset(e->dow, 0, (LAST_DOW - FIRST_DOW + 1));
 			e->flags |= DOW_STAR;
-		} else if (!strcmp("weekly", cmd)) {
+		}
+		else if (!strcmp("weekly", cmd)) {
 			bit_set(e->minute, 0);
 			bit_set(e->hour, 0);
-			bit_nset(e->dom, 0, (LAST_DOM-FIRST_DOM+1));
-			bit_nset(e->month, 0, (LAST_MONTH-FIRST_MONTH+1));
+			bit_nset(e->dom, 0, (LAST_DOM - FIRST_DOM + 1));
+			bit_nset(e->month, 0, (LAST_MONTH - FIRST_MONTH + 1));
 			bit_set(e->dow, 0);
 			e->flags |= DOW_STAR;
-		} else if (!strcmp("daily", cmd) || !strcmp("midnight", cmd)) {
+		}
+		else if (!strcmp("daily", cmd) || !strcmp("midnight", cmd)) {
 			bit_set(e->minute, 0);
 			bit_set(e->hour, 0);
-			bit_nset(e->dom, 0, (LAST_DOM-FIRST_DOM+1));
-			bit_nset(e->month, 0, (LAST_MONTH-FIRST_MONTH+1));
-			bit_nset(e->dow, 0, (LAST_DOW-FIRST_DOW+1));
-		} else if (!strcmp("hourly", cmd)) {
+			bit_nset(e->dom, 0, (LAST_DOM - FIRST_DOM + 1));
+			bit_nset(e->month, 0, (LAST_MONTH - FIRST_MONTH + 1));
+			bit_nset(e->dow, 0, (LAST_DOW - FIRST_DOW + 1));
+		}
+		else if (!strcmp("hourly", cmd)) {
 			bit_set(e->minute, 0);
-			bit_nset(e->hour, 0, (LAST_HOUR-FIRST_HOUR+1));
-			bit_nset(e->dom, 0, (LAST_DOM-FIRST_DOM+1));
-			bit_nset(e->month, 0, (LAST_MONTH-FIRST_MONTH+1));
-			bit_nset(e->dow, 0, (LAST_DOW-FIRST_DOW+1));
+			bit_nset(e->hour, 0, (LAST_HOUR - FIRST_HOUR + 1));
+			bit_nset(e->dom, 0, (LAST_DOM - FIRST_DOM + 1));
+			bit_nset(e->month, 0, (LAST_MONTH - FIRST_MONTH + 1));
+			bit_nset(e->dow, 0, (LAST_DOW - FIRST_DOW + 1));
 			e->flags |= HR_STAR;
-		} else {
+		}
+		else {
 			ecode = e_timespec;
 			goto eof;
 		}
@@ -163,13 +167,13 @@ load_entry(FILE *file, void (*error_func)(), struct passwd *pw, char **envp) {
 			ecode = e_cmd;
 			goto eof;
 		}
-	} else {
+	}
+	else {
 		Debug(DPARS, ("load_entry()...about to parse numerics\n"))
 
-		if (ch == '*')
+			if (ch == '*')
 			e->flags |= MIN_STAR;
-		ch = get_list(e->minute, FIRST_MINUTE, LAST_MINUTE,
-			      PPC_NULL, ch, file);
+		ch = get_list(e->minute, FIRST_MINUTE, LAST_MINUTE, PPC_NULL, ch, file);
 		if (ch == EOF) {
 			ecode = e_minute;
 			goto eof;
@@ -180,8 +184,7 @@ load_entry(FILE *file, void (*error_func)(), struct passwd *pw, char **envp) {
 
 		if (ch == '*')
 			e->flags |= HR_STAR;
-		ch = get_list(e->hour, FIRST_HOUR, LAST_HOUR,
-			      PPC_NULL, ch, file);
+		ch = get_list(e->hour, FIRST_HOUR, LAST_HOUR, PPC_NULL, ch, file);
 		if (ch == EOF) {
 			ecode = e_hour;
 			goto eof;
@@ -192,8 +195,7 @@ load_entry(FILE *file, void (*error_func)(), struct passwd *pw, char **envp) {
 
 		if (ch == '*')
 			e->flags |= DOM_STAR;
-		ch = get_list(e->dom, FIRST_DOM, LAST_DOM,
-			      PPC_NULL, ch, file);
+		ch = get_list(e->dom, FIRST_DOM, LAST_DOM, PPC_NULL, ch, file);
 		if (ch == EOF) {
 			ecode = e_dom;
 			goto eof;
@@ -202,8 +204,7 @@ load_entry(FILE *file, void (*error_func)(), struct passwd *pw, char **envp) {
 		/* month
 		 */
 
-		ch = get_list(e->month, FIRST_MONTH, LAST_MONTH,
-			      MonthNames, ch, file);
+		ch = get_list(e->month, FIRST_MONTH, LAST_MONTH, MonthNames, ch, file);
 		if (ch == EOF) {
 			ecode = e_month;
 			goto eof;
@@ -214,8 +215,7 @@ load_entry(FILE *file, void (*error_func)(), struct passwd *pw, char **envp) {
 
 		if (ch == '*')
 			e->flags |= DOW_STAR;
-		ch = get_list(e->dow, FIRST_DOW, LAST_DOW,
-			      DowNames, ch, file);
+		ch = get_list(e->dow, FIRST_DOW, LAST_DOW, DowNames, ch, file);
 		if (ch == EOF) {
 			ecode = e_dow;
 			goto eof;
@@ -238,13 +238,13 @@ load_entry(FILE *file, void (*error_func)(), struct passwd *pw, char **envp) {
 	unget_char(ch, file);
 
 	if (!pw) {
-		char		*username = cmd;	/* temp buffer */
+		char *username = cmd;	/* temp buffer */
 
 		Debug(DPARS, ("load_entry()...about to parse username\n"))
-		ch = get_string(username, MAX_COMMAND, file, " \t\n");
+			ch = get_string(username, MAX_COMMAND, file, " \t\n");
 
-		Debug(DPARS, ("load_entry()...got %s\n",username))
-		if (ch == EOF || ch == '\n' || ch == '*') {
+		Debug(DPARS, ("load_entry()...got %s\n", username))
+			if (ch == EOF || ch == '\n' || ch == '*') {
 			ecode = e_cmd;
 			goto eof;
 		}
@@ -255,7 +255,7 @@ load_entry(FILE *file, void (*error_func)(), struct passwd *pw, char **envp) {
 			goto eof;
 		}
 		Debug(DPARS, ("load_entry()...uid %ld, gid %ld\n",
-			      (long)pw->pw_uid, (long)pw->pw_gid))
+				(long) pw->pw_uid, (long) pw->pw_gid))
 	}
 
 	if ((e->pwd = pw_dup(pw)) == NULL) {
@@ -272,78 +272,78 @@ load_entry(FILE *file, void (*error_func)(), struct passwd *pw, char **envp) {
 		goto eof;
 	}
 	if (!env_get("SHELL", e->envp)) {
-		if (glue_strings(envstr, sizeof envstr, "SHELL",
-				 _PATH_BSHELL, '=')) {
+		if (glue_strings(envstr, sizeof envstr, "SHELL", _PATH_BSHELL, '=')) {
 			if ((tenvp = env_set(e->envp, envstr)) == NULL) {
 				ecode = e_memory;
 				goto eof;
 			}
 			e->envp = tenvp;
-		} else
+		}
+		else
 			log_it("CRON", getpid(), "error", "can't set SHELL", 0);
 	}
 	if (!env_get("HOME", e->envp)) {
-		if (glue_strings(envstr, sizeof envstr, "HOME",
-				 pw->pw_dir, '=')) {
+		if (glue_strings(envstr, sizeof envstr, "HOME", pw->pw_dir, '=')) {
 			if ((tenvp = env_set(e->envp, envstr)) == NULL) {
 				ecode = e_memory;
 				goto eof;
 			}
 			e->envp = tenvp;
-		} else
+		}
+		else
 			log_it("CRON", getpid(), "error", "can't set HOME", 0);
 	}
 #ifndef LOGIN_CAP
 	/* If login.conf is in used we will get the default PATH later. */
 	if (!env_get("PATH", e->envp)) {
-		if (glue_strings(envstr, sizeof envstr, "PATH",
-				 _PATH_DEFPATH, '=')) {
+		if (glue_strings(envstr, sizeof envstr, "PATH", _PATH_DEFPATH, '=')) {
 			if ((tenvp = env_set(e->envp, envstr)) == NULL) {
 				ecode = e_memory;
 				goto eof;
 			}
 			e->envp = tenvp;
-		} else
+		}
+		else
 			log_it("CRON", getpid(), "error", "can't set PATH", 0);
 	}
 #endif /* LOGIN_CAP */
-	if (glue_strings(envstr, sizeof envstr, "LOGNAME",
-			 pw->pw_name, '=')) {
+	if (glue_strings(envstr, sizeof envstr, "LOGNAME", pw->pw_name, '=')) {
 		if ((tenvp = env_set(e->envp, envstr)) == NULL) {
 			ecode = e_memory;
 			goto eof;
 		}
 		e->envp = tenvp;
-	} else
+	}
+	else
 		log_it("CRON", getpid(), "error", "can't set LOGNAME", 0);
 #if defined(BSD) || defined(__linux)
-	if (glue_strings(envstr, sizeof envstr, "USER",
-			 pw->pw_name, '=')) {
+	if (glue_strings(envstr, sizeof envstr, "USER", pw->pw_name, '=')) {
 		if ((tenvp = env_set(e->envp, envstr)) == NULL) {
 			ecode = e_memory;
 			goto eof;
 		}
 		e->envp = tenvp;
-	} else
+	}
+	else
 		log_it("CRON", getpid(), "error", "can't set USER", 0);
 #endif
 
 	Debug(DPARS, ("load_entry()...about to parse command\n"))
 
-	/* If the first character of the command is '-' it is a cron option.
-	 */
-	while ((ch = get_char(file)) == '-') {
+		/* If the first character of the command is '-' it is a cron option.
+		 */
+		while ((ch = get_char(file)) == '-') {
 		switch (ch = get_char(file)) {
 		case 'q':
 			e->flags |= DONT_LOG;
 			Skip_Nonblanks(ch, file)
-			break;
+				break;
 		default:
 			ecode = e_option;
 			goto eof;
 		}
 		Skip_Blanks(ch, file)
-		if (ch == EOF || ch == '\n') {
+			if (ch == EOF || ch == '\n') {
 			ecode = e_cmd;
 			goto eof;
 		}
@@ -353,7 +353,7 @@ load_entry(FILE *file, void (*error_func)(), struct passwd *pw, char **envp) {
 	/* Everything up to the next \n or EOF is part of the command...
 	 * too bad we don't know in advance how long it will be, since we
 	 * need to malloc a string for it... so, we limit it to MAX_COMMAND.
-	 */ 
+	 */
 	ch = get_string(cmd, MAX_COMMAND, file, "\n");
 
 	/* a file without a \n before the EOF is rude, so we'll complain...
@@ -372,11 +372,11 @@ load_entry(FILE *file, void (*error_func)(), struct passwd *pw, char **envp) {
 
 	Debug(DPARS, ("load_entry()...returning successfully\n"))
 
-	/* success, fini, return pointer to the entry we just created...
-	 */
-	return (e);
+		/* success, fini, return pointer to the entry we just created...
+		 */
+		return (e);
 
- eof:
+  eof:
 	if (e->envp)
 		env_free(e->envp);
 	if (e->pwd)
@@ -387,14 +387,13 @@ load_entry(FILE *file, void (*error_func)(), struct passwd *pw, char **envp) {
 	while (ch != '\n' && !feof(file))
 		ch = get_char(file);
 	if (ecode != e_none && error_func)
-		(*error_func)(ecodes[(int)ecode]);
+		(*error_func) (ecodes[(int) ecode]);
 	return (NULL);
 }
 
 static int
-get_list(bitstr_t *bits, int low, int high, const char *names[],
-	 int ch, FILE *file)
-{
+get_list(bitstr_t * bits, int low, int high, const char *names[],
+	int ch, FILE * file) {
 	int done;
 
 	/* we know that we point to a non-blank character here;
@@ -403,14 +402,13 @@ get_list(bitstr_t *bits, int low, int high, const char *names[],
 	 * assume the same thing.
 	 */
 
-	Debug(DPARS|DEXT, ("get_list()...entered\n"))
+	Debug(DPARS | DEXT, ("get_list()...entered\n"))
 
-	/* list = range {"," range}
-	 */
-	
-	/* clear the bit string, since the default is 'off'.
-	 */
-	bit_nclear(bits, 0, (high-low+1));
+		/* list = range {"," range}
+		 */
+		/* clear the bit string, since the default is 'off'.
+		 */
+		bit_nclear(bits, 0, (high - low + 1));
 
 	/* process all ranges
 	 */
@@ -427,26 +425,25 @@ get_list(bitstr_t *bits, int low, int high, const char *names[],
 	/* exiting.  skip to some blanks, then skip over the blanks.
 	 */
 	Skip_Nonblanks(ch, file)
-	Skip_Blanks(ch, file)
+		Skip_Blanks(ch, file)
 
-	Debug(DPARS|DEXT, ("get_list()...exiting w/ %02x\n", ch))
+		Debug(DPARS | DEXT, ("get_list()...exiting w/ %02x\n", ch))
 
-	return (ch);
+		return (ch);
 }
 
 
 static int
-get_range(bitstr_t *bits, int low, int high, const char *names[],
-	  int ch, FILE *file)
-{
+get_range(bitstr_t * bits, int low, int high, const char *names[],
+	int ch, FILE * file) {
 	/* range = number | number "-" number [ "/" number ]
 	 */
 
 	int i, num1, num2, num3;
 
-	Debug(DPARS|DEXT, ("get_range()...entering, exit won't show\n"))
+	Debug(DPARS | DEXT, ("get_range()...entering, exit won't show\n"))
 
-	if (ch == '*') {
+		if (ch == '*') {
 		/* '*' means "first-last" but can still be modified by /step
 		 */
 		num1 = low;
@@ -454,7 +451,8 @@ get_range(bitstr_t *bits, int low, int high, const char *names[],
 		ch = get_char(file);
 		if (ch == EOF)
 			return (EOF);
-	} else {
+	}
+	else {
 		ch = get_number(&num1, low, names, ch, file, ",- \t\n");
 		if (ch == EOF)
 			return (EOF);
@@ -467,7 +465,8 @@ get_range(bitstr_t *bits, int low, int high, const char *names[],
 				return (EOF);
 			}
 			return (ch);
-		} else {
+		}
+		else {
 			/* eat the dash
 			 */
 			ch = get_char(file);
@@ -499,7 +498,8 @@ get_range(bitstr_t *bits, int low, int high, const char *names[],
 		ch = get_number(&num3, 0, PPC_NULL, ch, file, ", \t\n");
 		if (ch == EOF || num3 == 0)
 			return (EOF);
-	} else {
+	}
+	else {
 		/* no step.  default==1.
 		 */
 		num3 = 1;
@@ -510,7 +510,7 @@ get_range(bitstr_t *bits, int low, int high, const char *names[],
 	 * proposed conceptually by bob@acornrc, syntactically
 	 * designed then implemented by paul vixie).
 	 */
-	for (i = num1;  i <= num2;  i += num3)
+	for (i = num1; i <= num2; i += num3)
 		if (EOF == set_element(bits, low, high, i)) {
 			unget_char(ch, file);
 			return (EOF);
@@ -520,8 +520,8 @@ get_range(bitstr_t *bits, int low, int high, const char *names[],
 }
 
 static int
-get_number(int *numptr, int low, const char *names[], int ch, FILE *file,
-    const char *terms) {
+get_number(int *numptr, int low, const char *names[], int ch, FILE * file,
+	const char *terms) {
 	char temp[MAX_TEMPSTR], *pc;
 	int len, i;
 
@@ -529,7 +529,7 @@ get_number(int *numptr, int low, const char *names[], int ch, FILE *file,
 	len = 0;
 
 	/* first look for a number */
-	while (isdigit((unsigned char)ch)) {
+	while (isdigit((unsigned char) ch)) {
 		if (++len >= MAX_TEMPSTR)
 			goto bad;
 		*pc++ = ch;
@@ -546,7 +546,7 @@ get_number(int *numptr, int low, const char *names[], int ch, FILE *file,
 
 	/* no numbers, look for a string if we have any */
 	if (names) {
-		while (isalpha((unsigned char)ch)) {
+		while (isalpha((unsigned char) ch)) {
 			if (++len >= MAX_TEMPSTR)
 				goto bad;
 			*pc++ = ch;
@@ -554,30 +554,28 @@ get_number(int *numptr, int low, const char *names[], int ch, FILE *file,
 		}
 		*pc = '\0';
 		if (len != 0 && strchr(terms, ch)) {
-			for (i = 0;  names[i] != NULL;  i++) {
-				Debug(DPARS|DEXT,
-					("get_num, compare(%s,%s)\n", names[i],
-					temp))
-				if (!strcasecmp(names[i], temp)) {
-					*numptr = i+low;
+			for (i = 0; names[i] != NULL; i++) {
+				Debug(DPARS | DEXT,
+					("get_num, compare(%s,%s)\n", names[i], temp))
+					if (!strcasecmp(names[i], temp)) {
+					*numptr = i + low;
 					return (ch);
 				}
 			}
 		}
 	}
 
-bad:
+  bad:
 	unget_char(ch, file);
 	return (EOF);
 }
 
-static int
-set_element(bitstr_t *bits, int low, int high, int number) {
-	Debug(DPARS|DEXT, ("set_element(?,%d,%d,%d)\n", low, high, number))
+static int set_element(bitstr_t * bits, int low, int high, int number) {
+	Debug(DPARS | DEXT, ("set_element(?,%d,%d,%d)\n", low, high, number))
 
-	if (number < low || number > high)
+		if (number < low || number > high)
 		return (EOF);
 
-	bit_set(bits, (number-low));
+	bit_set(bits, (number - low));
 	return (OK);
 }
